@@ -3,7 +3,7 @@ hmKeywords:"",
 hmTitle:"Table Compare File Format Settings",
 hmDescription:"Specify the file format to be used when reading the left and\/or right files.  The default selection is Detected, which means the file format will be selected based on file...",
 hmPrevLink:"sessiontablespecs.html",
-hmNextLink:"sessiontablecolumns.html",
+hmNextLink:"sessiontablesheets.html",
 hmParentLink:"sessiontable.html",
 hmBreadCrumbs:"<a href=\"settings_reference.html\">Settings Reference<\/a> &gt; <a href=\"session_settings.html\">Session Settings<\/a> &gt; <a href=\"sessiontable.html\">Table Compare<\/a>",
 hmTitlePath:"Settings Reference > Session Settings > Table Compare > Format",
